@@ -1,6 +1,6 @@
 %%%-------------------------------------------------------------------
 %%% @author Evgeny Khramtsov <ekhramtsov@process-one.net>
-%%% @copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
+%%% @copyright (C) 2002-2021 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -20,7 +20,7 @@
 %% API
 -export([start/0, stop/0]).
 -export([parse/2, parse/3, validate/2, fail/2, replace_macros/1]).
--export([format_error/1, format_error/2, format_ctx/1]).
+-export([format_error/1, format_error/2, format_ctx/1, include_files/3]).
 %% Simple types
 -export([pos_int/0, pos_int/1, non_neg_int/0, non_neg_int/1]).
 -export([int/0, int/2, number/1, octal/0]).
@@ -1151,7 +1151,7 @@ parse_uri(URL) when is_binary(URL) ->
     parse_uri(to_string(URL)); % OTP =< 19's http_uri:parse/1 expects strings.
 parse_uri(URL) ->
     case http_uri:parse(URL) of
-	{ok, {Scheme, _UserInfo, Host, Port0, Path, _Query}} ->
+	{ok, {Scheme, _UserInfo, Host, Port0, _Path, _Query}} ->
 	    Port = if is_integer(Port0) -> Port0;
 		      true -> undefined
 		   end,
